.. _technical-label:

Technical documentation
=======================

.. image:: https://img.shields.io/pypi/v/pytrip98.svg
        :target: https://pypi.python.org/pypi/pytrip98


.. image:: https://readthedocs.org/projects/pytrip/badge/?version=latest
        :target: https://readthedocs.org/projects/pytrip/?badge=latest
        :alt: Documentation Status


.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - |ghactions| |appveyor|
    * - package
      - |version| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/pytrip/badge/?style=flat
    :target: https://readthedocs.org/projects/pytrip
    :alt: Documentation Status

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/pytrip/pytrip?branch=master&svg=true
    :alt: Appveyor Build Status
    :target: https://ci.appveyor.com/project/grzanka/pytrip

.. |ghactions| image:: https://github.com/github/docs/actions/workflows/main.yml/badge.svg?branch=master
    :alt: Github Action Build Status
    :target: https://github.com/pytrip/pytrip/actions

.. |version| image:: https://img.shields.io/pypi/v/pytrip98.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pytrip98

.. |downloads| image:: https://img.shields.io/pypi/dm/pytrip98.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/pytrip98

.. |wheel| image:: https://img.shields.io/pypi/wheel/pytrip98.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pytrip98

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/pytrip98.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pytrip98

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/pytrip98.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/pytrip98

.. end-badges


Documentation
=============

https://pytrip.readthedocs.io/

